@@ -1424,8 +1424,29 @@ class ExcludeTest(CoverageTest):
             e = 5
             f = 6#\tpragma:\tno cover
             g = 7
+            ...
+            i = 9
+            ...     # we don't care about this line
+            k = 11
+            def foo12(): ...  # do nothing
+            async def bar13():   ...
+            def method14(self) ->None: ...
+            def method15(   # 15
+                self,
+                some_arg: str = "Hello",
+            ): ...
+            def method19(self): return a[1,...]
+            def method20(
+                self,
+                some_args,
+            ) -> int: ...
+            x = 24
+            def method25(
+                self,
+            ):  return a[1,...]
+            def f28(): print("(well): ... #2 false positive!")
             """,
-            lines=[1,3,5,7],
+            lines=[1,3,5,7,9,11,19,24,25]
         )
 
     def test_two_excludes(self) -> None:
@@ -1506,13 +1527,13 @@ class ExcludeTest(CoverageTest):
         self.check_coverage("""\
             x, y = [0], [1]
             if x == [2]:
-                raise NotImplementedError   # pragma: NO COVER
+                raise NotImplementedError   # NOCOVPLZ
             if all(_ == __ for _, __ in zip(x, y)):
-                raise NotImplementedError   # pragma: NO COVER
+                raise NotImplementedError   # NOCOVPLZ
             """,
             lines=[1,2,4],
             missing="",
-            excludes=['#pragma: NO COVER'],
+            excludes=['# NOCOVPLZ'],
             branchz="23 24 45 4.",
             branchz_missing="",
         )
